@@ -686,7 +686,7 @@ test_that("get parameter using generalised linear mixed model", {
 ###############################################################################
 test_that("Bivaraite regression for correlated values", {
   datafile <- system.file("extdata", "hsb2.dta", package = "packDAMipd")
-  mydata <- foreign::read.dta(datafile)
+  mydata <- haven::read_dta(datafile)
   results_sureg <- use_seemingly_unrelated_regression("read", "math",
     dataset = mydata,
     indep_var = "female", covariates1 = c("as.numeric(ses)", "socst"),
